;; Generated package description from clipboard-collector.el  -*- no-byte-compile: t -*-
(define-package "clipboard-collector" "0.3.0.20190215.154741" "Collect clipboard entries according to regex rules" '((emacs "25")) :commit "72131b92b74b24e1c1851233ddbfc1225f33322a" :authors '(("Clemens Radermacher" . "clemera@posteo.net")) :maintainer '("Clemens Radermacher" . "clemera@posteo.net") :keywords '("convenience") :url "https://github.com/clemera/clipboard-collector")
